SQLAlchemy 0.4 Documentation - module sqlalchemy.databases.postgres

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4 Last Updated: 08/22/07 15:48:11

### module sqlalchemy.databases.postgres

### Module Functions

def descriptor()

### class PGArray(TypeEngine,Concatenable)

def __init__(self, item_type)

Construct a new `PGArray`.

def bind_processor(self, dialect)
def dialect_impl(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class PGBigInteger(PGInteger)

def get_col_spec(self)
back to section top

### class PGBinary(Binary)

def get_col_spec(self)
back to section top

### class PGBoolean(Boolean)

def get_col_spec(self)
back to section top

### class PGChar(CHAR)

def get_col_spec(self)
back to section top

### class PGCompiler(DefaultCompiler)

def for_update_clause(self, select)
def get_select_precolumns(self, select)
def limit_clause(self, select)
def uses_sequences_for_inserts(self)
back to section top

### class PGDate(Date)

def get_col_spec(self)
back to section top

### class PGDateTime(DateTime)

def get_col_spec(self)
back to section top

### class PGDefaultRunner(DefaultRunner)

def get_column_default(self, column, isinsert=True)
def visit_sequence(self, seq)
back to section top

### class PGDialect(DefaultDialect)

def __init__(self, use_oids=False, server_side_cursors=False, **kwargs)

Construct a new `PGDialect`.

def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def do_begin_twophase(self, connection, xid)
def do_commit_twophase(self, connection, xid, is_prepared=True, recover=False)
def do_executemany(self, c, statement, parameters, context=None)

We need accurate rowcounts for updates, inserts and deletes.

`psycopg2` is not nice enough to produce this correctly for an executemany, so we do our own executemany here.

def do_prepare_twophase(self, connection, xid)
def do_recover_twophase(self, connection)
def do_rollback_twophase(self, connection, xid, is_prepared=True, recover=False)
def get_default_schema_name(self, connection)
def has_sequence(self, connection, sequence_name)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def last_inserted_ids(self)
def oid_column_name(self, column)
def reflecttable(self, connection, table, include_columns)
def table_names(self, connection, schema)
def type_descriptor(self, typeobj)
back to section top

### class PGExecutionContext(DefaultExecutionContext)

def create_cursor(self)
def get_result_proxy(self)
def post_exec(self)
back to section top

### class PGFloat(Float)

def get_col_spec(self)
back to section top

### class PGIdentifierPreparer(IdentifierPreparer)

back to section top

### class PGInet(TypeEngine)

def get_col_spec(self)
back to section top

### class PGInteger(Integer)

def get_col_spec(self)
back to section top

### class PGInterval(TypeEngine)

def get_col_spec(self)
back to section top

### class PGNumeric(Numeric)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class PGSchemaDropper(SchemaDropper)

def visit_sequence(self, sequence)
back to section top

### class PGSchemaGenerator(SchemaGenerator)

def get_column_specification(self, column, **kwargs)
def visit_sequence(self, sequence)
back to section top

### class PGSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class PGString(String)

def get_col_spec(self)
back to section top

### class PGText(TEXT)

def get_col_spec(self)
back to section top

### class PGTime(Time)

def get_col_spec(self)
back to section top